import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import componentTheme from '../../Tokens/components/breadcrumbs';

const OuterCrumb = reset.span`
  background-color: ${p => p.theme.crumbColor};
  height: 18px;
  width: 18px;
  opacity: 0.15;
  border-radius: 50%;
  display: inline-block;
  position: absolute;
`;

const InnerCrumb = reset.span`
  height: 8px;
  width: 8px;
  background-color: ${props => {
  if (props.state === 'complete' || props.state === 'active') {
    return '#4300E2';
  }
  return 'grey';
}};
  border-radius: 50%;
  display: inline-block;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-top: -4px;
  margin-left: -4px;
`;

const CrumbContainer = reset.div`
  ${props => props.onClick && 'cursor: pointer;'}
  position: relative;
  width: 18px;
  height: 18px;
  display: inline-block;
`;

var _ref = React.createElement(OuterCrumb, null);

const renderCrumb = (crumb, idx) => React.createElement(
  CrumbContainer,
  { key: idx, onClick: crumb.handleClick },
  crumb.state === 'active' && _ref,
  React.createElement(InnerCrumb, { state: crumb.state })
);

const Breadcrumbs = props => {
  const { data } = props;
  return React.createElement(
    ThemeProvider,
    { theme: componentTheme },
    React.createElement(
      'div',
      null,
      data && data.map(renderCrumb)
    )
  );
};

Breadcrumbs.propTypes = process.env.NODE_ENV !== "production" ? {
  data: PropTypes.array
} : {};

export default Breadcrumbs;