import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider, css } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';
import componentTheme from '../../Tokens/components/button';

const primaryStyle = css`
  background-color: ${p => p.theme.primary.backgroundColor};
  border-color: ${p => p.theme.primary.borderColor};
  color: ${p => p.theme.primary.color};
  &:hover {
    background-color: ${p => p.theme.primary.hover.backgroundColor};
    border-color: ${p => p.theme.primary.hover.borderColor};
    color: ${p => p.theme.primary.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.primary.active.backgroundColor};
    border-color: ${p => p.theme.primary.active.borderColor};
    color: ${p => p.theme.primary.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.primary.disabled.backgroundColor};
    border-color: ${p => p.theme.primary.disabled.borderColor};
    color: ${p => p.theme.primary.disabled.color};
  }
`;

const standardStyle = css`
  background-color: ${p => p.theme.standard.backgroundColor};
  border-color: ${p => p.theme.standard.borderColor};
  color: ${p => p.theme.standard.color};
  &:hover {
    background-color: ${p => p.theme.standard.hover.backgroundColor};
    border-color: ${p => p.theme.standard.hover.borderColor};
    color: ${p => p.theme.standard.hover.color};
  }
  &:active {
    background-color: ${p => p.theme.standard.active.backgroundColor};
    border-color: ${p => p.theme.standard.active.borderColor};
    color: ${p => p.theme.standard.active.color};
  }
  &:disabled {
    background-color: ${p => p.theme.standard.disabled.backgroundColor};
    border-color: ${p => p.theme.standard.disabled.borderColor};
    color: ${p => p.theme.standard.disabled.color};
  }
`;
const themes = {
  standard: standardStyle,
  primary: primaryStyle
};

export const ButtonComponent = reset.button.attrs({
  noWrap: p => p.noWrap,
  variant: p => p.variant || 'standard'
})`
  outline: 0;
  cursor: pointer;
  border-radius: ${p => p.theme.base.borderRadius}px;
  font-size: ${p => p.theme.base.fontSize}px;
  line-height: ${p => p.theme.base.lineHeight}px;
  font-weight: ${p => p.theme.base.fontWeight};
  min-width: ${p => p.theme.base.minWidth};
  padding-top: ${p => p.theme.base.paddingTop};
  padding-bottom: ${p => p.theme.base.paddingBottom};
  padding-left: ${p => p.theme.base.paddingLeft};
  padding-right: ${p => p.theme.base.paddingRight};
  margin-top: ${p => p.theme.base.marginTop};
  margin-bottom: ${p => p.theme.base.marginBottom};
  border-width: ${p => p.theme.base.borderWidth};
  border-style: ${p => p.theme.base.borderStyle};
  ${p => themes[p.variant] || themes.standard}};
  ${p => !p.noWrap && noWrap};
`;

const Button = props => React.createElement(
  ThemeProvider,
  { theme: componentTheme },
  React.createElement(ButtonComponent, props)
);
// export const Anchor = Button.withComponent('a');

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the component to not wrap.
   */
  noWrap: PropTypes.bool,
  /**
   * The theme variant of the button
   */
  variant: PropTypes.oneOf(['standard', 'primary'])
} : {};

Button.defaultProps = {
  noWrap: true,
  variant: 'standard'
};

export default Button;