import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import Tick from '../Svg/Tick';
import componentTheme from '../../Tokens/components/checkbox';

const BoxContainer = reset.div`
  width: ${p => p.theme.width}px;
  height: ${p => p.theme.height}px;
  box-sizing: border-box;
  margin-right: 12px;
  border-width: 1px;
  border-style: solid;
  border-radius: 4px;
  border-color: ${p => {
  if (p.disabled) {
    return p.theme.unchecked.disabled.border.color;
  }
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.default.border.color;
  }
  return p.theme.unchecked.default.border.color;
}};
  background-color: ${p => {
  if (p.disabled) {
    return p.theme.unchecked.disabled.background.color;
  }
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.default.background.color;
  }
  return p.theme.unchecked.default.background.color;
}};
`;

export const CheckboxComponent = reset.div`
  display: flex;
  user-select: none;
  font-family: ${p => p.theme.typography.fontFamily};
  font-size: ${p => p.theme.typography.body.fontSize}px;
  line-height: ${p => p.theme.typography.body.lineHeight}px;
  color: ${p => p.theme.unchecked.default.text.color};
  margin: 18px 0;
  cursor: default;
  &:hover {
    ${BoxContainer} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.hover.border.color;
  }
  return p.theme.unchecked.hover.border.color;
}};
          background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.hover.background.color;
  }
  return p.theme.unchecked.hover.background.color;
}};
    }
  }
  &:active {
    ${BoxContainer} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.focus.border.color;
  }
  return p.theme.unchecked.focus.border.color;
}}
          background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.focus.background.color;
  }
  return p.theme.unchecked.focus.background.color;
}}
    }
  }
`;

const Checkbox = props => React.createElement(
  ThemeProvider,
  { theme: componentTheme },
  React.createElement(
    CheckboxComponent,
    _extends({}, props, {
      onClick: () => {
        if (!props.disabled) {
          props.onClick();
        }
      }
    }),
    React.createElement(
      BoxContainer,
      _extends({}, props, { onClick: () => null }),
      props.checked && React.createElement(Tick, {
        style: {
          padding: '5px',
          boxSizing: 'border-box'
        },
        color: (props.error || props.disabled) && 'black',
        size: '30px'
      })
    ),
    props.label
  )
);

Checkbox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Checks the box
   */
  checked: PropTypes.bool.isRequired,
  /**
   * Disable checkbox
   */
  disabled: PropTypes.bool,
  /**
   * Error state
   */
  error: PropTypes.bool,
  /**
   * Sets the label for the checkbox
   */
  label: PropTypes.string.isRequired,
  /**
   * onClick handler
   */
  onClick: PropTypes.func
} : {};

Checkbox.defaultProps = {
  label: '',
  checked: false
};

export default Checkbox;