import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';

const ListBlockComponent = reset.div`
  font-family: ${p => p.theme.typography.fontFamily};
  font-size: ${p => p.theme.typography.body.fontSize}px;
  line-height: ${p => p.theme.typography.body.lineHeight}px;
  padding-bottom: ${p => p.theme.typography.body.paddingBottom}px;
  color: ${p => p.theme.typography.body.color};
  ${props => props.align && `text-align: ${props.align};`};
  ${props => props.noWrap && noWrap};
  &:first-child {
    padding-top: ${p => p.theme.typography.body.paddingTop}px;
  }
  border-bottom: 1px solid ${p => p.theme.colors.grey200};
`;

const ListBlock = props => React.createElement(
  ThemeProvider,
  { theme: x => x },
  React.createElement(ListBlockComponent, props)
);

ListBlock.propTypes = process.env.NODE_ENV !== "production" ? {
  align: PropTypes.oneOf(['inherit', 'left', 'center', 'right', 'justify']),
  children: PropTypes.node,
  color: PropTypes.string,
  gutterBottom: PropTypes.bool,
  noWrap: PropTypes.bool
} : {};

ListBlock.defaultProps = {
  align: 'inherit',
  color: 'default',
  gutterBottom: false,
  noWrap: false
};

export default ListBlock;