import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import componentTheme from '../../Tokens/components/checkbox';

const Radio = props => React.createElement(
  ThemeProvider,
  { theme: componentTheme },
  React.createElement(
    RadioComponent,
    props,
    React.createElement(
      Circle,
      props,
      props.checked && _ref
    ),
    props.label
  )
);

const Circle = reset.div`
  width: ${p => p.theme.width}px;
  height: ${p => p.theme.height}px;
  border-radius: ${p => p.theme.width}px;
  border-width: 1px;
  border-style: solid;
  color: ${p => p.theme.colors.grey300};
  background: ${p => p.theme.colors.white};
  margin-right: 12px;
  display: flex;
  align-items: center;
  justify-content: center;
  border-color: ${p => {
  if (p.disabled) {
    return p.theme.unchecked.disabled.border.color;
  }
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.default.border.color;
  }
  return p.theme.unchecked.default.border.color;
}};
  background-color: ${p => {
  if (p.disabled) {
    return p.theme.unchecked.disabled.background.color;
  }
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.default.background.color;
  }
  return p.theme.unchecked.default.background.color;
}};
`;

const RadioComponent = reset.div`
  display: flex;
  margin: 18px 0;
  &:hover {
    ${Circle} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.hover.border.color;
  }
  return p.theme.unchecked.hover.border.color;
}};
      background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.hover.background.color;
  }
  return p.theme.unchecked.hover.background.color;
}};
    }
  }
  &:active {
    ${Circle} {
      border-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.border.color;
  }
  if (p.checked) {
    return p.theme.checked.focus.border.color;
  }
  return p.theme.unchecked.focus.border.color;
}}
      background-color: ${p => {
  if (p.disabled) return '';
  if (p.error) {
    return p.theme.unchecked.error.background.color;
  }
  if (p.checked) {
    return p.theme.checked.focus.background.color;
  }
  return p.theme.unchecked.focus.background.color;
}}
    }
  }
`;

const Dot = reset.div`
  width: 8px;
  height: 8px;
  border-radius: 8px;
  background-color: ${p => p.theme.colors.white};
`,
      _ref = React.createElement(Dot, null);

Radio.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Checks the radio button
   */
  checked: PropTypes.bool.isRequired,
  /**
   * Disable Radio
   */
  disabled: PropTypes.bool,
  /**
   * Error state
   */
  error: PropTypes.bool,
  /**
   * Sets the label for the Radio
   */
  label: PropTypes.string.isRequired,
  /**
   * onClick handler
   */
  onClick: PropTypes.func
} : {};

Radio.defaultProps = {
  label: '',
  checked: false
};

export default Radio;