import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import { Option, Container, OptionsContainer, OptionsScrollContainer, Mask } from './SelectComponents';
import { Label } from '../TextField/TextFieldComponents';
import TextField from '../TextField/TextField';
import Dropdown from './Dropdown';
import componentTheme from '../../Tokens/components/select';

class Select extends Component {
  constructor(props) {
    super(props);

    this.onTextFieldFocus = () => {
      this.handleShowOptions();
    };

    this.handleHideOptions = () => {
      this.setState({
        optionsShowing: false
      });
    };

    this.handleShowOptions = () => {
      this.setState({
        optionsShowing: true
      });
    };

    this.select = value => {
      if (value !== null && value !== undefined && value !== this.state.value) {
        this.props.onChange(value);
      }
      this.setState({
        optionsShowing: false
      });
    };

    this.handleToggle = () => {
      if (this.state.optionsShowing) {
        this.handleHideOptions();
      } else {
        this.handleShowOptions();
      }
    };

    this.handleSearchTextChange = value => {
      this.props.searchChange(value);
    };

    this.state = {
      optionsShowing: false,
      options: props.options
    };
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.options !== this.props.options) {
      this.setState({
        options: nextProps.options
      });
    }
  }

  render() {
    const { width, searchable, label, value, valueKey, labelKey } = this.props;
    const { optionsShowing, options } = this.state;
    return React.createElement(
      ThemeProvider,
      { theme: componentTheme },
      React.createElement(
        Container,
        { width: width },
        React.createElement(Mask, { show: optionsShowing, onClick: this.handleHideOptions }),
        label && React.createElement(
          Label,
          null,
          label
        ),
        searchable ? React.createElement(TextField, {
          value: value && options.length > 0 && options.find(option => option[valueKey] === value)[labelKey],
          style: { paddingTop: 0, paddingBottom: 6 },
          onFocus: this.onTextFieldFocus,
          onChange: this.handleSearchTextChange
        }) : React.createElement(Dropdown, {
          value: options.length > 0 && options.find(option => option[valueKey] === value)[labelKey],
          onClick: this.handleToggle,
          isOpen: optionsShowing,
          onOpen: this.handleShowOptions,
          onClose: this.handleHideOptions
        }),
        React.createElement(
          OptionsContainer,
          { size: options.length, hasLabel: !!label, show: optionsShowing },
          React.createElement(
            OptionsScrollContainer,
            null,
            options.length < 1 && React.createElement(
              Option,
              { onClick: () => this.select() },
              'No results'
            ),
            options.map(d => React.createElement(
              Option,
              { onClick: () => this.select(d[valueKey]) },
              d[labelKey]
            ))
          )
        )
      )
    );
  }
}

Select.propTypes = process.env.NODE_ENV !== "production" ? {
  label: PropTypes.string,
  labelKey: PropTypes.string,
  onChange: PropTypes.func.isRequired,
  options: PropTypes.array.isRequired,
  placeholder: PropTypes.string,
  searchable: PropTypes.bool.isRequired,
  searchChange: PropTypes.func,
  value: PropTypes.string,
  valueKey: PropTypes.string,
  width: PropTypes.string
} : {};

Select.defaultProps = {
  label: null,
  valueKey: 'value',
  labelKey: 'label',
  options: [],
  placeholder: 'Choose',
  searchable: false,
  searchChange: () => {},
  onChange: () => {},
  value: null
};

export default Select;