import React from 'react';
import PropTypes from 'prop-types';
import * as reset from '../reset';
import { BodyComponent } from '../Text/Body';

export const SelectContainer = props => React.createElement(
  SelectBox,
  { onClick: props.onClick },
  React.createElement(
    Placeholder,
    null,
    props.value || props.placeholder
  ),
  React.createElement(
    ArrowContainer,
    { isOpen: props.isOpen },
    '\u25B2'
  )
);

export const Container = reset.div`
  position: relative;
  width: ${p => p.width};
  margin: ${p => p.theme.spacing.marginVertical}px;
`;

SelectContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  isOpen: PropTypes.bool,
  onClick: PropTypes.func,
  placeholder: PropTypes.string,
  value: PropTypes.object
} : {};

const Placeholder = BodyComponent.extend`
  flex-grow: 1;
  padding-left: ${p => p.theme.paddingHorizontal}px;
  padding-top: ${p => p.theme.paddingVertical}px;
  padding-bottom: ${p => p.theme.paddingVertical}px;
  user-select: none;
`;

const ArrowContainer = reset.div`
  transform: ${p => p.isOpen ? '' : 'rotate(180deg)'};
  display: flex;
  align-items: center;
  padding: ${p => p.theme.paddingVertical}px ${p => p.theme.paddingHorizontal}px;
  user-select: none;
  color: ${p => p.theme.colors.grey400};
`;

const SelectBox = reset.div`
  cursor: arrow;
  display: flex;
  position: relative;
  min-width: 100px;
  height: ${p => p.theme.typography.body.lineHeight + p.theme.paddingVertical * 2}px;
  border-width: 1px;
  border-style: solid;
  border-color: ${props => {
  if (props.disabled) {
    return props.theme.disabled.borderColor;
  }
  if (props.error) {
    return props.theme.error.borderColor;
  }
  if (props.isFocused) {
    return props.theme.focus.borderColor;
  }
  return props.theme.borderColor;
}};
  border-radius: 4px;
  background-color: ${props => props.theme.colors.white};
  &:hover {
    border-color:${props => {
  if (props.error || props.disabled || props.isFocused) return '';
  return props.theme.hover.borderColor;
}}
  }
`;

export const Option = BodyComponent.extend`
  flex: 1;
  padding-top: ${p => p.theme.paddingVertical}px;
  padding-bottom: ${p => p.theme.paddingVertical}px;
  :first-child {
    padding-top: 0;
  }
  :last-child {
    padding-bottom: 0;
  }
`;

export const OptionsContainer = reset.div`
  z-index: 100;
  position: absolute;
  height: ${p => {
  let size = p.size;
  if (p.size > 3) {
    size = 3;
  } else if (p.size < 1) {
    size = 1;
  }
  return `${(p.theme.typography.body.lineHeight + p.theme.paddingVertical * 2) * size + 2}px`;
}}
  top: ${p => p.theme.typography.body.lineHeight + p.theme.paddingVertical * 2 + 6 + (p.hasLabel && 30)}px;
  width: 100%;
  background-color: ${p => p.theme.colors.white};
  display: ${p => p.show ? 'flex' : 'none'};
  border-width: 1px;
  border-style: solid;
  border-color: ${props => props.theme.borderColor};
  border-radius: 4px;
`;

export const OptionsScrollContainer = reset.div`
  flex-grow: 1;
  overflow-y: auto;
  margin: ${p => p.theme.paddingVertical}px ${p => p.theme.paddingHorizontal}px;
  /* width */
  ::-webkit-scrollbar {
      width: 4px;
  }

  /* Track */
  ::-webkit-scrollbar-track {
      background: ${p => p.theme.colors.grey200};
      border-radius: 4px;
  }

  /* Handle */
  ::-webkit-scrollbar-thumb {
      background: ${p => p.theme.colors.grey400};
      border-radius: 4px;
  }
`;

export const Mask = reset.div`
  position: fixed;
  display: ${p => p.show ? 'block' : 'none'};
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 100;
`;