import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';
import componentTheme from '../../Tokens/components/text';

export const SubheadingComponent = reset.p`
  font-family: ${p => p.theme.typography.fontFamily};
  font-weight: ${p => p.theme.typography.subheading.fontWeight};
  font-size: ${p => p.theme.typography.subheading.fontSize}px;
  line-height: ${p => p.theme.typography.subheading.lineHeight}px;
  padding-top: ${p => p.theme.typography.subheading.paddingTop}px;
  padding-bottom: ${p => p.theme.typography.subheading.paddingBottom}px;
  color: ${p => p.theme.typography.subheading.color};
  ${props => props.align && `text-align: ${props.align};`};
  ${props => props.noWrap && noWrap};
`;

const Subheading = props => React.createElement(
  ThemeProvider,
  { theme: componentTheme },
  React.createElement(SubheadingComponent, props)
);

Subheading.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the text-align on the component.
   */
  align: PropTypes.oneOf(['inherit', 'left', 'center', 'right', 'justify']),
  /**
   * The content of the component.
   */
  children: PropTypes.node,
  /**
   * The content of the component.
   */
  color: PropTypes.string,
  /**
   * The content of the component.
   */
  gutterBottom: PropTypes.bool,
  /**
   * If `true`, the text will not wrap, but instead will truncate with an ellipsis.
   */
  noWrap: PropTypes.bool
} : {};

Subheading.defaultProps = {
  align: 'inherit',
  color: 'default',
  gutterBottom: false,
  noWrap: false
};

export default Subheading;