import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import * as reset from '../reset';
import { noWrap } from '../utils';

export const TitleComponent = reset.h1`
  font-family: ${p => p.theme.typography.fontFamily};
  font-size: ${p => p.theme.typography.title.fontSize}px;
  line-height: ${p => p.theme.typography.title.lineHeight}px;
  padding-top: ${p => p.theme.typography.title.paddingTop}px;
  padding-bottom: ${p => p.theme.typography.title.paddingBottom}px;
  color: ${p => p.theme.typography.title.color};
  ${props => props.align && `text-align: ${props.align};`};
  ${props => props.noWrap && noWrap};
`;

const Title = props => React.createElement(
  ThemeProvider,
  { theme: x => x },
  React.createElement(TitleComponent, props)
);

Title.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the text-align on the component.
   */
  align: PropTypes.oneOf(['inherit', 'left', 'center', 'right', 'justify']),
  /**
   * The content of the component.
   */
  children: PropTypes.node,
  /**
   * The content of the component.
   */
  color: PropTypes.string,
  /**
   * The content of the component.
   */
  gutterBottom: PropTypes.bool,
  /**
   * If `true`, the text will not wrap, but instead will truncate with an ellipsis.
   */
  noWrap: PropTypes.bool
} : {};

Title.defaultProps = {
  align: 'inherit',
  color: 'default',
  gutterBottom: false,
  noWrap: false
};

export default Title;