import React from 'react';
import PropTypes from 'prop-types';
import { ThemeProvider } from 'styled-components';
import { Label, Toggle, Link, ErrorText, Caption, TextFieldComponent, TextInput, TextInputContainer } from './TextFieldComponents';
import componentTheme from '../../Tokens/components/textfield';

class TextField extends React.Component {
  constructor(...args) {
    var _temp;

    return _temp = super(...args), this.state = {
      inputFocused: false
    }, this.onFocus = () => {
      this.setState({ inputFocused: true });
      this.props.onFocus();
    }, _temp;
  }

  render() {
    const {
      label,
      caption,
      onChange,
      toggle,
      error,
      link,
      onToggle,
      disabled,
      style,
      theme,
      type,
      value
    } = this.props;
    const { inputFocused } = this.state;
    return React.createElement(
      ThemeProvider,
      { theme: componentTheme },
      React.createElement(
        TextFieldComponent,
        { style: style },
        label && React.createElement(
          Label,
          null,
          label
        ),
        caption && React.createElement(
          Caption,
          null,
          caption
        ),
        React.createElement(
          TextInputContainer,
          {
            isFocused: inputFocused,
            theme: theme,
            disabled: disabled,
            error: error
          },
          React.createElement(TextInput, {
            value: value,
            type: type,
            onChange: event => onChange(event.target.value),
            disabled: disabled,
            onFocus: this.onFocus,
            onBlur: () => this.setState({ inputFocused: false })
          }),
          toggle && React.createElement(
            Toggle,
            { onClick: onToggle },
            toggle
          )
        ),
        error && React.createElement(
          ErrorText,
          null,
          error
        ),
        link && React.createElement(
          Link,
          { href: link.href, wholeLine: true, variation: 'small' },
          link.label
        )
      )
    );
  }
}

TextField.propTypes = process.env.NODE_ENV !== "production" ? {
  caption: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.string,
  label: PropTypes.string,
  link: PropTypes.shape({
    label: PropTypes.string,
    href: PropTypes.string
  }),
  onChange: PropTypes.func,
  onFocus: PropTypes.func,
  onToggle: PropTypes.func,
  style: PropTypes.object,
  theme: PropTypes.object,
  toggle: PropTypes.string,
  type: PropTypes.string,
  value: PropTypes.string
} : {};

TextField.defaultProps = {
  label: null,
  error: null,
  link: null,
  caption: null,
  type: 'text',
  onFocus: () => {}
};

export default TextField;