import React from 'react';
import { css } from 'styled-components';
import PropTypes from 'prop-types';
import * as reset from '../reset';

const regularStyle = css`
  font-size: ${p => p.theme.typography.body.fontSize}px;
  line-height: ${p => p.theme.typography.body.lineHeight}px;
`;

const largeStyle = css`
  font-size: ${p => p.theme.typography.navigation.fontSize}px;
  line-height: ${p => p.theme.typography.navigation.lineHeight}px;
`;

const UnderlinedOptionContainer = props => React.createElement(
  UnderlinedOptionComponent,
  null,
  React.createElement(Text, props),
  props.variation !== 'large' && React.createElement(Line, { variation: props.variation, color: props.borderColor })
);

UnderlinedOptionContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Underline color if underlined
   */
  borderColor: PropTypes.string,
  /**
   * Label
   */
  children: PropTypes.node.isRequired,
  /**
   * Regular or small UnderlinedOption.
   */
  variation: PropTypes.oneOf(['large', 'regular'])
} : {};

const Text = reset.div`
  display: inline-block;
  padding-bottom: ${p => p.theme.spacing.gap}px;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
  ${p => p.variation === 'large' && `border-bottom: 1px solid ${p.borderColor};`}
`;

const Line = reset.div`
  width: ${p => p.variation === 'large' ? '100%' : '54px'};
  height: 1px;
  background-color: ${p => p.color};
`;

const UnderlinedOptionComponent = reset.div`
  font-family: ${p => p.theme.typography.fontFamily};
  margin-top: ${p => p.theme.spacing.marginVertical}px;
  margin-bottom: ${p => p.theme.spacing.marginVertical}px;
  color: ${p => props => props.variation === 'large' ? p.theme.typography.title.color : p.theme.typography.body.color};
  display: block;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
`;

export default UnderlinedOptionContainer;